@@ -16,7 +16,8 @@ simCovariates = function(hab.range=30, probs=c(1/3,2/3) , river.loc=50)
 ################################################################################
 {
  coords = cbind(x=rep(seq(.5,99.5,1),each=100), y=rep(seq(.5,99.5,1), 100))
- habRaw = GaussRF(coords, model="gauss", grid=FALSE, param=c(0,1,0,hab.range/sqrt(-log(0.05))))
+ #habRaw = GaussRF(coords, model="gauss", grid=FALSE, param=c(0,1,0,))
+ habRaw = RFsimulate(model=RMgauss(var=1, scale=hab.range/sqrt(-log(0.05))), x=coords[,"x"], y=coords[,"y"])@data[,1]
  quan = c(-Inf,quantile(habRaw, probs),Inf)
  habitat=as.numeric(cut(habRaw,quan))
  d = abs(coords[,'x']-river.loc)/max(abs(coords[,'x']-river.loc))
